﻿* Encoding: UTF-8.

************************************************************.
************************************************************.

***    HANDLING DATA USING SPSS

***    Information Services - Research Data Service
***    University of Edinburgh (UoE)

***    Based on materials originally developed from the ESRC-funded Longitudinal Data Analysis for Social Science Researchers project
***    Website: http://www.restore.ac.uk/Longitudinal/
***    Original materials created by: Dr Paul Lambert and Dr Vernon Gayle
	
***    This version created by: Bob Sanders (UoE)

***    File name:       MANTRA_SPSS_UKDS_9236_v1.sps
***    Last updated:  OCTOBER 2024

***    Feel free to use and adapt this syntax file.

************************************************************.
************************************************************.

***   This syntax file assumes you have a number of files downloaded to your machine:.

***    1. MANTRA_UKDA-9236-RAW_DATA.csv - 
            The raw data in comma-delimited format (a standard non-proprietry data format), which we will read into SPSS.
***    2. MANTRA_UKDA-9236_ADDVARS.sav
             An SPSS system (data) file containing additional variables, which will be linked to our main data.
***    3. MANTRA_UKDA-9236_ADDCASES.sav
             An SPSS system (data) file containing additional cases, which will be linked to our main data.
***    4. MANTRA_SPSS_UKDS_9236_v1.sps
             An SPSS syntax file that contains the data management commands for this module (if you're reading this, you already have the file!)

***   NOTE: The data used in this course are derived from the British Social Attitudes Survey, 2021, Health Care and Equalities: Open Access Teaching Dataset.
***   https://doi.org/10.5255/UKDA-SN-9236-1
***   These data have been modified from the original data set for the puposes of creating this course.    

***    The above files (including the original BSA data file and supporting documentation) can be downloaded from the MANTRA website:
***    https://mantra.ed.ac.uk/softwarepracticals.html
***    See: Data handling in SPSS 29 > Zipped data files.

***    This syntax file was originally created in 2007, and was updated in 2024 using SPSS v29.
***    It should also work with previous versions of SPSS.

***    For access to SPSS at the University of Edinburgh, please see the following page:
***    https://edin.ac/3XCC48T

************************************************************.
************************************************************.
***   This course / syntax file is organised into 8 main parts:

***   Part 1:   INTRODUCTION
***                 1a. SOME COMMENTS ON USING SPSS SYNTAX FILES
***                 1b. ORGANIZING YOUR FILES
***   Part 2.   DEFINING LOCATION PATHS
***   Part 3:   IMPORTING / OPENING DATA FILE
***   Part 4:   UNDERSTANDING AND DESCRIBING THE DATA
***   Part 5:   EXPLORING AND DESCRIBING VARIABLES
***   Part 6:   COMMON DATA MANAGEMENT TECHNIQUES
***   Part 7:   DATA LINKAGE: ADD CASES AND ADD FILES
***   Part 8:   EXPORTING DATA TO OTHER FORMATS

***   These exercises will introduce core data management and preparation activities.
***   You are recommended to practice adapting and developing your own syntax as you progress.

************************************************************.
************************************************************.

***   Part 1: INTRODUCTION

***   1a. SOME COMMENTS ON USING SPSS SYNTAX FILES.

***       NOTE: You may want to adjust the font size in SPSS: View > Fonts > Select the font size in the right-hand column.

***       This is an interactive command file (i.e. a syntax file).
***       Syntax files can be open and run in the syntax editor window in SPSS.
***       On an interactive command file, you write out the textual SPSS commands
***       and invoke them, typically in groups of a few sequential commands at a time.

***       Commands are run by highlighting the command line or lines you wish to invoke 
***       and then pressing the 'Run Selection' button (green arrow/play button). 
***       Alternatively, you can press 'Ctrl+R' to run the selected command/s.

***       Commands are not case sensitive, e.g.
***       FREQUENCIES VARIABLES=var1
***       is the same as 
***       frequencies variables=var1.

***       Many commands can also be abbreviated
***       e.g. fre for frequencies.

***       Gradually learning the textual SPSS commands is the valuable skill in learning SPSS.
***       The best way is to begin working through example syntax files, such as this one.
***       In time you will start to remember the commands you most commonly use.

***       Additionally, you should learn how and where to find information on the necessary SPSS commands 
***       - i.e. from the SPSS manuals and inbuilt help system, the numerous online SPSS resources,
***       or using the 'Paste' button (rather than the 'Ok' button) when running commands from the GUI       
***       interface (this pastes the syntax to run the menu-specified command into the current syntax window).
***       NOTE: pasted commands need to be run, by highlighting and selecting 'Run Selection' (or pressing Ctrl+R).

***   Comment:
***       Notes & comments throughout this example syntax file give some explanation of what each  
***       command is doing, but they don't cover everything. Best is to try to work out yourself 
***       what each line is doing, but ask the instructors for clarification if needed.

***       In an SPSS syntax file, full stops are the 'command line delimiter'. A new command is
***       indicated by the next line following a full stop. Any new command, including a comment,
***       is interpreted by SPSS as unfinished until the next full stop is reached.
***    !! BEWARE - FORGETTING FULL STOPS IS THE MOST COMMON SPSS SYNTAX PROGRAMMING MISTAKE !!.

***       Comments can be added by beginning a line with a *
***       Starting a line with a * means that SPSS will ignore the rest of the line, and any following lines,
***       until a full stop is reached.

***       Comments are useful for making notes for yourself.

***       Beware that it is easy to inadvertently comment out an active command by forgetting
***       to close a previous comment with a full stop.

***   ADVANCED:
***       If you run a whole syntax file at once [as a 'batch file'], it is also possible to specify other
***       symbols or line breaks as the command line delimiter (i.e. instead of a full stop).

***   Comment:
***       If running a group of command lines together at once in SPSS, if any of your command  
***       lines includes an error, SPSS will simply move to the next command line and continue 
***       to run from that point onwards.
***       NOTE: this is different from the way Stata processes command lines.
***       Beware that this can sometimes mean a group of command lines run and give the 
***       appearance of being successful, when actually an earlier error took place (i.e. it may      
***       not be immediately obvious an error occurred).

***       SPSS processes command syntax by running the syntax on whatever current data file 
***       it has in memory. If you have more than one data file open you need to ensure you are
***       running the relevant commands on the correct data file (see Active DataSet: at the top of this syntax window).
***       To avoid any confusion, it is best practice to have only one data file window open at a time.

***       When a command is run, SPSS displays the output generated by the relevant command/s
***       in the 'Output window'.
***       IT IS STRONGLY RECOMMENDED THAT YOU CHANGE THE SETTINGS ON YOUR OUTPUT WINDOW 
***       FROM THE DEFAULT SETTINGS TO MAKE CLEAR THE UNDERLYING COMMAND PROCESSING.
***       See '3.7. Changing SPSS Edit > Options display defaults' in the PDF workbook (pgs. 9-11) for more information.

***       For most social scientists, processing SPSS through the syntax file editor is appropriate
***       for most purposes. The next step up is learning to program in SPSS, which concerns
***       writing programmes (macros) and batch files (whole files processed in one go), to run 
***       complex tasks - we'll save that for another time!

***   SEE ALSO : http://www.longitudinal.stir.ac.uk/SPSS_support.html

**************************************************************.
**************************************************************.

***    Part 1b. ORGANISING YOUR FILES.

***    When working with data and any accompanying files you should adopt a sensible file and folder naming strategy.
***    This will help you to quickly locate the files you need, and help you to easily find and 
***    understand your files without having to open them to check.

***    The zip file for this course includes an example folder structure, as follows:

***        RAW_DATA
***           - Keep your raw data in a dedicated folder (e.g. RAW_DATA).
***           - WARNING: be careful never to overwrite your original raw data file/s!!!

***        WORKING_DATA
***            - As you work on your data, save versions of your modified data files in a separate folder (e.g. WORKING_DATA).
***            - This ensures you will never accidentally change and overwrite your original raw data file.
***            - Every time we save we should version our data, by appending the file name with v2, v3, v4 etc.
***            - NOTE: Saving our data by running the save command from the syntax file (rather than using the SPSS menu)
***            - will ensure we maintain a clear record of the steps taken between versions, and how each new data file was generated.

***        CLEAN_DATA 
***            - Once you have finished cleaning and preparing your data, save a copy of the finished dataset in a separate folder (e.g. CLEAN_DATA).

***        SYNTAX
***            - Keep copies of your syntax file/s in a dedicated folder (e.g. SYNTAX).

***        OUTPUT
***            - You may wish to save Outputs from your analysis, so using a dedicated folder (e.g. OUTPUT) will help you to organise your work.

************************************************************.
************************************************************.

***    Part 2. DEFINING LOCATION PATHS  

***    We will begin by telling SPSS where to find our data files, and where we will save our working data files.
***    Defining the paths to the folders we will be using at the beginning means we don't need to repeatedly tell SPSS where to find or .
***    save our files, making it simpler to load and save our data files when we come back to work on them later.
***    Further, defining location paths means our syntax files can more easily transferred to work on another machine
***    (e.g. to allow others to run our analysis on another PC).

***   The following macros tell SPSS where to find/save the relevant files on your machine.
***   NOTE: you will need to run the commands to specify the paths each time you start a new SPSS session.

***       THE PATH BELOW ARE USED WHEN RUNNING THIS COURSE ON PCs IN THE UNIVERSITY OF EDINBURGH TRAINING ROOMS.
***       THESE ARE COMMENTED OUT.
*define !working_data () '\\sg.datastore.ed.ac.uk\sg\usd\groups\isskills\Home\tr08-003\Handling_data_using_SPSS\working_data\' !enddefine. 
*define !clean_data () '\\sg.datastore.ed.ac.uk\sg\usd\groups\isskills\Home\tr08-003\Handling_data_using_SPSS\clean_data\' !enddefine. 

***   NOTE:
***        IF YOU WANT TO USE THIS SYNTAX FILE ON YOUR OWN COMPUTER YOU MUST EDIT THE PATHS BELOW
***        TO THE EQUIVALENT FOLDER LOCATIONS ON YOUR OWN MACHINE.

***   NOTE: The path should begin with ' and end with \' - don't forget to include a single backslash \ at the end of the path.

***        You can name your folders in whatever way you wish, but make sure the names are meaningful and easy to understand.

***    TASK:
***        Find and copy the path to the WORKING_DATA folder on your machine.
***        Paste the path below to complete the command, then highlight and 'Run Selection' (or press Ctrl+R).
define !working_data () 'paste_path_to_the_WORKING_DATA_folder_on_your_machine_here\' !enddefine. 

***        Find and copy the path to the CLEAN_DATA folder on your machine.
***        Paste the path below to complete the command, then highlight and 'Run Selection' (or press Ctrl+R).
define !clean_data () 'paste_path_to_the_CLEAN_DATA_folder_on_your_machine_here\' !enddefine. 

***        For example, the lines 223-224 use the DEFINE command to specify the paths to my own WORKING_DATA 
***        and CLEAN_DATA folders (NOTE: the commands below start with * so are 'commented out').
*define !working_data () 'M:\MANTRA\Handling_Data_Using_SPSS\WORKING_DATA\' !enddefine.
*define !clean_data () 'M:\MANTRA\Handling_Data_Using_SPSS\CLEAN_DATA\' !enddefine.

***        NOTE: OPTIONAL
***        You can also define more paths in the same way (e.g. to tell SPSS where to save your outputs and syntax)
***        NOTE: For example, you can define the paths to your SYNTAX and OUTPUT folders by replacing the folder location in the following commands.
*define !syntax () 'paste_path_to_the_SYNTAX_folder_on_your_machine_here\' !enddefine.
*define !output () 'paste_path_to_the_OUTPUT_folder_on_your_machine_here\' !enddefine.

***   However, this step is optional and we can continue to proceed with our data management tasks without the SYNTAX or OUTPUT folders being defined.

************************************************************.
************************************************************.

***   Part 3. IMPORTING / OPENING DATA FILE.

***    If you already have data that are in an SPSS file format (file extension .sav), you can simply open
***    that file to begin working with your data in SPSS (File > Open > Data). 

***    However, if you have data stored in other types of files, such as an Excel spreadsheet or a text 
***    file (e.g. .csv or .tsv), you will firstly need to import the file into SPSS - specifying how SPSS should 
***    read the file in - before you can save it in the standard SPSS file format (.sav).

***    IMPORTANT:
***        Though we almost always use syntax for our work, it can sometimes be simpler to use the drop-down menu for
***        performing certain tasks:
***        e.g. opening a csv (comma separated values) data file for the first time is one of those tasks.

***   From the SPSS Menu, select: File > Import Data > CSV Data
***   Navigate to the RAW_DATA folder and select the .csv file and select 'Open' then 'Paste' (rather than 'OK').

***   The syntax to import the .csv file into SPSS will be pasted at the bottom of your active syntax window (it may be this one).
***   Find and copy (Ctrl+C) the newly generated syntax (from PRESERVE. to EXECUTE.)
***   and paste it below, overwriting the syntax below (line 262 to 304).

***   After pasting the syntax below, run the command by highlighting the whole command
***   (e.g. from PRESERVE. to EXECUTE.) and clicking the 'Run Selection' button (or using 'Ctrl+R').

*        COMMAND SYNTAX TO IMPORT .CSV DATA INTO SPSS:.
PRESERVE.
SET DECIMAL DOT.

GET DATA  /TYPE=TXT
  /FILE="M:\MANTRA\Handling_Data_Using_SPSS\RAW_DATA\MANTRA_UKDS-9236-RAW_DATA.csv"
  /ENCODING='UTF8'
  /DELIMITERS=","
  /QUALIFIER='"'
  /ARRANGEMENT=DELIMITED
  /FIRSTCASE=2
  /DATATYPEMIN PERCENTAGE=95.0
  /VARIABLES=
  serial_scrambled AUTO
  BSA21_final_wt AUTO
  DVSex21 AUTO
  Ragecat AUTO
  HHincomex AUTO
  RClassGP AUTO
  hedqual2x AUTO
  MarStat6x AUTO
  HhlChlGpdx AUTO
  PMSx AUTO
  HomoSexx AUTO
  Partyfwx AUTO
  Politicsx AUTO
  Votedx AUTO
  Spend1x AUTO
  dolex AUTO
  TAXSPENDx AUTO
  EQOPPGAYx AUTO
  EQOPPTx AUTO
  CHOPWOMMx AUTO
  EQOPPBLKx AUTO
  TBirCertx AUTO
  EqOpDisx AUTO
  EqOpMhx AUTO
  welfare2 AUTO
  leftrigh AUTO
  libauth AUTO
  /MAP.
RESTORE.
CACHE.
EXECUTE.

***   NOTE:
***       Sometimes you may need to run a command using the SPSS GUI (i.e. the menu interface), for example, if you
***       don't know the correct syntax to perform a particular command.

***       In these instances, try using the [Paste] rather than the [Ok] button, which will paste the syntax to run the 
***       command to the bottom of your current syntax file. You will then be able to run exactly the same command again  
***       without needing to navigate through a potentially complicated series of steps (which may be difficult to replicate
***       exactly if needed).

***       This approach will help you to build syntax files containing the range of commands needed to easily perform common
***        (and not so common) data management, data preparation and data analysis tasks repeatedly and consistently.

***       Additionally, the syntax in your file can be used, modified and adapted to suit your needs in other situations.
***       For example, once you have the syntax to generate or derive a variable, it is relatively simple to paste and edit the 
***       syntax to derive a different variable.

***   After running the command to import the data, the Data Editor window will open.
***   There are 3 views in the Data Editor window, which you can flick between:

***   Data View - shows the variable (column) by case (row) view of the data.
***   Variable View - shows information about the variables in our dataset. 
***   Overview - provides summary information about the dataset.

***   Check the Data Editor Window to see that the dataset was opened.
***   Does it look correct? i.e. check that cells are populated, we have the expected number 
***   of variables, and the dataset is structured correctly.

***   NOTE:
***   When importing a csv file, SPSS will automatically determine the variable type (Numeric/String)
***   and Measurement Level (Nominal/Ordinal/Scale). However, these may not be correct
***   and we should check for mistakes.

***   Check the Variable View.
***   You should see that SPSS has determined:
***   09/27 variables are Numeric/Nominal
***   18/27 variables are Numeric/Scale

***   Some of these are incorrect and we will need to modify the incorrect ones (see '6.6. Incorrectly specified variables' in the PDF workbook, pg. 22).
VARIABLE LEVEL
    Ragecat HHincomex RClassGP hedqual2x PMSx HomoSexx Politicsx TAXSPENDx 
    EQOPPGAYx EQOPPTx CHOPWOMMx EQOPPBLKx TBirCertx EqOpDisx EqOpMhx (ORDINAL).
VARIABLE LEVEL
    Votedx Spend1x dolex (NOMINAL).
	
***   Once we're happy that the data have been opened in SPSS correctly (see '6.5. Checking for errors' in the PDF workbook, pg. 21), 
***   we should now save it as an SPSS system (data) file (.sav) in the appropriate folder.
***   NOTE: we will save our data to the Working Data folder (specified earlier, line 215).

sav out=!WORKING_DATA+'MANTRA_UKDA-9236-v1.sav'.

***    NOTE: check the WORKING_DATA folder to see that the new file has been saved.
***    If the file does not appear then:

***        1. Check that the folder path was specified correctly (line 215).
***        2. Check you have actually run the 'define path' command (line 215).
***        3. Check you have run the 'sav out' command above (line 354).

***    NOTE: We'll now work with this data file for the rest of this course.

*****************************************************************.
*****************************************************************.

***   Part 4:   UNDERSTANDING AND DESCRIBING THE DATA.

***   Let's open our data file using the following syntax (or If you need to load your saved data again from this point for any reason, e.g. if you come back to this later).
***   NOTE: YOU NEED TO RUN THE COMMAND/S TO DEFINE YOUR FOLDERS (e.g. lines 215 and 219) AT THE START OF A NEW SPSS SESSION.
get file=!WORKING_DATA+'MANTRA_UKDA-9236-v1.sav'.
EXECUTE.

***   NOTE: Any output generated by a command will be displayed in the Output window.
***   A new Output window will open when you run your first comand each session.
***   The Output window will display any errors which occur after running a command (or series of commands).

***   Now let's look at ways of describing the data and its contents.
display dictionary.

***   This command gives us detailed information about our variables (see Output window).
***   The information is similar to the Variable View in the Data Editor window.

***   We can also find out information about an SPSS data file (.sav) without needing to open it:.
sysfile info !WORKING_DATA+'MANTRA_UKDA-9236-v1.sav'.

***   This gives us information on the data file (including number of cases and number of variables),
***   plus information about the variables (similar to information provided by 'display dictionary' command).
***   We can see from File Information > Data Information that the dataset has 5,175 cases and 27 variables. 

***   We can add more descriptive information about the dataset using the 'document' command.

document The British Social Attitudes survey (BSA) is the leading survey in Britain for assessing trends and
    changes in public opinions on social and political measures. Over the past four decades, the survey has become
    the main source of statistics on key national issues, which makes the survey valuable for policy making, 
    researchers, charity and media. The British Social Attitudes Open Teaching Dataset: Health Care and Equalities 
    2021 is a subsample from the original BSA 2021. The BSA 2021 open teaching dataset has variables focusing on
    important health care measures such as views and satisfaction with the National Health Service (NHS). The dataset
    also consists of variables that assess attitudes to equality and sexual relationships such as equality in workplace, 
    views about LGTB, and relationships outside marriage. The BSA 2021 teaching dataset includes variables that are
    also available in the 2017 and 2019 BSA teaching datasets to allow performing time-based and comparison 
    analyses (for example, variables that measure welfare and political situations and the scale variables). In addition, 
    the dataset contains sociodemographic variables such as age, gender, education, marital status, and socioeconomic
    classifications that can be used in exploring differences between socioeconomic status. For more information about 
    the original data, see the original BSA 2021 records in the UK Data Service data catalogue. You can also find 
    information about the British Social Attitudes Survey (BSA) in general.
    
*** We can look up the information with the following command.

display documents.

***    The big gap in our knowledge at the moment is understanding what each variable contains.
***    For example, what does each variable name refer to? What does a given variable value mean e.g. "1" for variable DVSex21? 
***    We will commonly want to add variable labels and value labels so that we can easily understand the what the
***    a given variable is, or what the different values of a categoprical variable mean. In particular, this will help when
***    we analyse our data - we need any tables or graphs we generate to be understandable!!! Adding variable and value labels
***    is a common task whenever we generate or derive new variables, and we can do this using syntax.

VARIABLE LABELS serial_scrambled 'Scrambled Individual Serial' .
 
VARIABLE LABELS BSA21_final_wt 'British Social Attitudes Survey 2021 - final weight' .

VARIABLE LABELS DVSex21 'What is your sex?' .
 VALUE LABELS DVSex21 
	    9.000000  'Prefer not to answer' 
	    8.000000  'Don~t know' 
	    2.000000  'Male' 
	    1.000000  'Female' 
	   -1.000000  'Not applicable' 
.
VARIABLE LABELS Ragecat 'Age of respondent(grouped) <7 category> dv' .
 VALUE LABELS Ragecat 
	    9.000000  'Prefer not to answer' 
	    8.000000  'Don~t know' 
	    7.000000  '65+' 
	    6.000000  '60-64' 
	    5.000000  '55-59' 
	    4.000000  '45-54' 
	    3.000000  '35-44' 
	    2.000000  '25-34' 
	    1.000000  '18-24' 
	   -1.000000  'Not applicable' 
.
VARIABLE LABELS HHincomex 'What is the total income of your household from all sources before tax?' .
 VALUE LABELS HHincomex 
	    9.000000  'Prefer not to answer' 
	    8.000000  'Don~t know' 
	    4.000000  '£4,351 per month or more' 
	    3.000000  '£2,561 - £4,350 per month' 
	    2.000000  '£1,411 - £2,560 per month' 
	    1.000000  'Less than £1,410 per month' 
	   -1.000000  'Not applicable' 
.
VARIABLE LABELS RClassGP 'NS-SEC analytic classes (self-coded)' .
 VALUE LABELS RClassGP 
	    8.000000  'Don~t know/Prefer not to answer' 
	    6.000000  'Not classifiable' 
	    5.000000  'Semi-routine and routine occupations' 
	    4.000000  'Lower supervisory and technical occupations' 
	    3.000000  'Small employers and own account workers' 
	    2.000000  'Intermediate occupations' 
	    1.000000  'Managerial and professional occupations' 
	   -1.000000  'Not applicable' 
.
VARIABLE LABELS hedqual2x 'Highest educational qualification attained' .
 VALUE LABELS hedqual2x 
	    4.000000  'No qualifications' 
	    3.000000  'GCSE/O Level/Standard Grade, vocational level2 or equivalent' 
	    2.000000  'Higher educ below degree (Diplomas, HNC, HND)/A levels/SCE H' 
	    1.000000  'Degree (equivalent + above)' 
.
VARIABLE LABELS MarStat6x 'Marital Status' .
 VALUE LABELS MarStat6x 
	    4.000000  'Single (never married/never in a civil partnership)' 
	    3.000000  'Widowed/surviving partner from a civil partnership' 
	    2.000000  'Separated/divorced/dissolved civil partnership' 
	    1.000000  'Married/in a civil partnership/living with a partner' 
.
VARIABLE LABELS HhlChlGpdx 'Children in household (grouped)' .
 VALUE LABELS HhlChlGpdx 
	    2.000000  'No' 
	    1.000000  'Yes' 
.
VARIABLE LABELS PMSx 'If a man and woman have sexual relations before marriage, what would your general opinion be?' .
 VALUE LABELS PMSx 
	    9.000000  'Prefer not to answer' 
	    8.000000  'Don~t know' 
	    6.000000  'It depends ' 
	    5.000000  'Not wrong at all' 
	    4.000000  'Rarely wrong ' 
	    3.000000  'Sometimes wrong' 
	    2.000000  'Mostly wrong' 
	    1.000000  'Always wrong' 
	   -1.000000  'Not applicable' 
.
VARIABLE LABELS HomoSexx 'What about sexual relations between two adults of the same sex?' .
 VALUE LABELS HomoSexx 
	    9.000000  'Prefer not to answer' 
	    8.000000  'Don~t know' 
	    6.000000  'It depends' 
	    5.000000  'Not wrong at all' 
	    4.000000  'Rarely wrong' 
	    3.000000  'Sometimes wrong' 
	    2.000000  'Mostly wrong' 
	    1.000000  'Always wrong' 
	   -1.000000  'Not applicable' 
.
VARIABLE LABELS Partyfwx 'Rs political party identification (party support/closest to/likely vote at next election)?' .
 VALUE LABELS Partyfwx 
	    6.000000  'Green Party' 
	    5.000000  'None' 
	    4.000000  'Other party' 
	    3.000000  'Liberal Democrat' 
	    2.000000  'Labour' 
	    1.000000  'Conservative' 
.
VARIABLE LABELS Politicsx 'How much interest do you have in politics?' .
 VALUE LABELS Politicsx 
	    9.000000  'Prefer not to answer' 
	    8.000000  'Don~t know' 
	    5.000000  'None at all' 
	    4.000000  'Not very much' 
	    3.000000  'Some' 
	    2.000000  'Quite a lot' 
	    1.000000  'A great deal' 
	   -1.000000  'Not applicable' 
.
VARIABLE LABELS Votedx 'Did you manage to vote in the general election?' .
 VALUE LABELS Votedx 
	    9.000000  'Prefer not to answer' 
	    8.000000  'Don~t know' 
	    3.000000  'Not applicable, I was not eligible to vote, or too young' 
	    2.000000  'No' 
	    1.000000  'Yes, voted' 
	   -1.000000  'Not applicable' 
.
VARIABLE LABELS Spend1x 'Which would be your highest priority for extra govt spending?' .
 VALUE LABELS Spend1x 
	   11.000000  'None of these' 
	   10.000000  'Overseas aid' 
	    9.000000  'Help for industry' 
	    8.000000  'Social security benefits' 
	    7.000000  'Police and prisons' 
	    6.000000  'Roads' 
	    5.000000  'Public transport' 
	    4.000000  'Housing' 
	    3.000000  'Health' 
	    2.000000  'Defence' 
	    1.000000  'Education' 
	   99.000000  'Prefer not to say' 
	   98.000000  'Don~t know' 
	   -1.000000  'Not applicable' 
.
VARIABLE LABELS dolex 'Opinions differ about the level of benefits for unemployed people. Which comes closest to your own view' .
 VALUE LABELS dolex 
	    9.000000  'Prefer not to answer' 
	    8.000000  'Don~t know' 
	    7.000000  ' Other specific answer not in codeframe' 
	    6.000000  'About right/in between' 
	    5.000000  'Both: unemployment benefit causes hardship to some, while ot' 
	    4.000000  'Both: unemployment benefit causes hardship but can~t be high' 
	    3.000000  'Neither' 
	    2.000000  'Benefits for unemployed people are too high and discourage t' 
	    1.000000  'Benefits for unemployed people are too low and cause hardshi' 
	   -1.000000  'Not applicable' 
.
VARIABLE LABELS TAXSPENDx 'If it had to choose, should govt reduce/increase/maintain levels of taxation and spending?' .
 VALUE LABELS TAXSPENDx 
	    9.000000  'Prefer not to answer' 
	    8.000000  'Don~t know' 
	    3.000000  'Increase taxes and spend more on health, education and socia' 
	    2.000000  'Keep taxes and spending on these services at the same level ' 
	    1.000000  'Reduce taxes and spend less on health, education and social ' 
	   -1.000000  'Not applicable' 
.
VARIABLE LABELS EQOPPGAYx 'Have equal opportunities have gone too far or not far enough for Lesbian, gay and bisexual people ' .
 VALUE LABELS EQOPPGAYx 
	    9.000000  'Prefer not to answer' 
	    8.000000  'Don~t know' 
	    5.000000  'Not gone nearly far enough' 
	    4.000000  'Not gone far enough' 
	    3.000000  'About right' 
	    2.000000  'Gone too far' 
	    1.000000  'Gone much too far' 
	   -1.000000  'Not applicable' 
.
VARIABLE LABELS EQOPPTx 'Have equal opportunities have gone too far or not far enough for Transgender people' .
 VALUE LABELS EQOPPTx 
	    9.000000  'Prefer not to answer' 
	    8.000000  'Don~t know' 
	    5.000000  'Not gone nearly far enough' 
	    4.000000  'Not gone far enough' 
	    3.000000  'About right' 
	    2.000000  'Gone too far' 
	    1.000000  'Gone much too far' 
	   -1.000000  'Not applicable' 
.
VARIABLE LABELS CHOPWOMMx 'Have equal opportunities have gone too far or not far enough for Women' .
 VALUE LABELS CHOPWOMMx 
	    9.000000  'Prefer not to answer' 
	    8.000000  'Don~t know' 
	    5.000000  'Not gone nearly far enough' 
	    4.000000  'Not gone far enough' 
	    3.000000  'About right' 
	    2.000000  'Gone too far' 
	    1.000000  'Gone much too far' 
	   -1.000000  'Not applicable' 
.
VARIABLE LABELS EQOPPBLKx 'Have equal opportunities have gone too far or not far enough for Black and Asian people' .
 VALUE LABELS EQOPPBLKx
	    9.000000  'Prefer not to answer' 
	    8.000000  'Don~t know' 
	    5.000000  'Not gone nearly far enough' 
	    4.000000  'Not gone far enough' 
	    3.000000  'About right' 
	    2.000000  'Gone too far' 
	    1.000000  'Gone much too far' 
	   -1.000000  'Not applicable' 
.
VARIABLE LABELS TBirCertx 'Should a person who is transgender be able to have the sex recorded on their birth certificate changed?' .
 VALUE LABELS TBirCertx
	    9.000000  'Prefer not to answer' 
	    8.000000  'Don~t know' 
	    5.000000  'Strongly disagree' 
	    4.000000  'Disagree' 
	    3.000000  'Neither agree nor disagree' 
	    2.000000  'Agree' 
	    1.000000  'Strongly agree' 
	   -1.000000  'Not applicable' 
.
VARIABLE LABELS EqOpDisx 'Have attempts to give people with physical impairments an equal chance in the workplace gone too far or not far enough?' .
 VALUE LABELS EqOpDisx 
	    9.000000  'Prefer not to answer' 
	    8.000000  'Don~t know' 
	    5.000000  'Not gone nearly far enough' 
	    4.000000  'Not gone far enough' 
	    3.000000  'About right' 
	    2.000000  'Gone too far' 
	    1.000000  'Gone much too far' 
	   -1.000000  'Not applicable' 
.
VARIABLE LABELS EqOpMhx 'Have attempts to give people with mental health conditions an equal chance in the workplace gone too far or not far enou' .
 VALUE LABELS EqOpMhx 
	    9.000000  'Prefer not to answer' 
	    8.000000  'Don~t know' 
	    5.000000  'Not gone nearly far enough' 
	    4.000000  'Not gone far enough' 
	    3.000000  'About right' 
	    2.000000  'Gone too far' 
	    1.000000  'Gone much too far' 
	   -1.000000  'Not applicable' 
.
VARIABLE LABELS welfare2 'Welfarism scale (welfhelp to proudwlf) dv' .
 VALUE LABELS welfare2 
	    9.000000  'Missing values' 
	    5.000000  'poor don~t deserve' 
	    1.000000  'sympathetic' 
	   -1.000000  'Not applicable' 
.
VARIABLE LABELS leftrigh 'Left-right scale (redistrb to indust4) dv' .
 VALUE LABELS leftrigh 
	    9.000000  'Missing values' 
	    5.000000  'right' 
	    1.000000  'left' 
	   -1.000000  'Not applicable' 
.
VARIABLE LABELS libauth 'Libertarian-authoritarian scale (TradVals to censor) dv' .
 VALUE LABELS libauth 
	    9.000000  'Missing values' 
	    5.000000  'authoritarian' 
	    1.000000  'libertarian' 
	   -1.000000  'Not applicable'.

***   We also need to specify which of the values are missing values - in this dataset we will
***   treat responses coded 'Prefer not to answer' 'Don't know' and 'Not applicable' as missing.
MISSING VALUES
DVSex21 Ragecat HHincomex RClassGP hedqual2x MarStat6x HhlChlGpdx PMSx HomoSexx Partyfwx 
Politicsx Votedx Spend1x dolex TAXSPENDx EQOPPGAYx EQOPPTx CHOPWOMMx EQOPPBLKx 
TBirCertx EqOpDisx EqOpMhx (-1 8 9).
MISSING VALUES welfare2 leftrigh libauth (-1 9).
MISSING VALUES Spend1x  (-1 98 99).
MISSING VALUES dolex (-1, 7 THRU 9).

***   PRO TIP:
**
***       Rather than clogging up your syntax file with lots of lines of variable and value label commands,
***       why not create a separate syntax file that you can run from this file?
**
***       This is an optional task, so feel free to skip ahead to the next part.
***       Copy the above VARIABLE / VALUE LABEL commands (lines 420 to 673) into a separate syntax file, and then
***       save the new syntax file in your syntax folder as 'MANTRA_DHT_add_labels.sps'.
***       then run the next command (on line 697).
***       NOTE:You need to have specified the SYNTAX folder (line 229)
***       and you need to remove the * at the beginning before running the command.

* include file=!syntax+'MANTRA_DHT_add_labels.sps'.

***   Now we've added the labels to our variables, let's look at how our dataset looks now.
display dictionary.
display labels.

***   Now let's save the updated data file.
 
sav out=!WORKING_DATA+'MANTRA_UKDA-9236-v2.sav'.

*****************************************************************.
*****************************************************************.

***    Well done, we now have a data file that we can easily understand and we can now begin to explore
***    and analyse our data.

*****************************************************************.
*****************************************************************.

***   Part 5:   EXPLORING AND DESCRIBING VARIABLES.

*****************************************************************.
*****************************************************************.

***   We have an SPSS data file, and we know how many variables and cases there are, 
***   and what the variables and values mean etc.

***   Now we will focus on the content of the variables to consider their frequencies, distributions, averages,
***   errors and missing values. This is a crucial step that provides vital info on what 
***   data management tasks we need to perform prior to analysis.

***   If we need to open the data file we saved, run the GET FILE command:.
***   NOTE: YOU NEED TO RUN THE COMMAND/S TO DEFINE YOUR FOLDERS (e.g. lines 215 and 219) AT THE START OF A NEW SPSS SESSION.
get file=!WORKING_DATA+'MANTRA_UKDA-9236-v2.sav'.
EXECUTE.

***   It is important to know what type of variables we have (see Variable View in the Data Editor window).
***   We can also use the following command to see a summary of our variables:.
display variables.

***   All of our variables are NUMERIC (i.e. there are no STRING variables) and
***   our dataset includes both CONTINUOUS (NUMERIC/SCALE) 
***   and CATEGORICAL (NUMERIC/ORDINAL & NUMERIC/NOMINAL) variables.

***   Now let's take a look at the variables.

***   When generating output, it is a good idea to show both values and value labels:.
set tnumbers both.

***   Remember that we can use upper or lower case, and commands can be shortened - 
***   the following 3 lines are the exact same command.
FREQUENCIES VARIABLES DVSex21.
frequencies variables DVSex21.
fre var DVSex21.

***   The DESCRIPTIVES and EXAMINE commands are used to analyse NUMERIC variables:.
descriptives variables =all.

***   We can also ask SPSS for particular statistics.
descriptives var
   welfare2 leftrigh libauth
   /statistics= mean min max stddev skewness.

***   The EXAMINE command gives us more detail and options than DESCRIPTIVES.
examine welfare2 leftrigh libauth.

***   Again, we can specify the particular statistics and graphs we want.
examine welfare2
   /plot boxplot stemleaf histogram
   /percentiles(5,25,50,75,95).

***   Let's take a look at our CATEGORICAL variables now.
frequencies variables=all.

***   The FREQUENCIES command will often produce tables for numeric variables, but these are often unhelpful
***   e.g. for CONTINUOUS variables.

frequencies variables
DVSex21 Ragecat HHincomex RClassGP hedqual2x MarStat6x HhlChlGpdx PMSx HomoSexx Partyfwx 
Politicsx Votedx Spend1x dolex TAXSPENDx EQOPPGAYx EQOPPTx CHOPWOMMx EQOPPBLKx 
TBirCertx EqOpDisx EqOpMhx welfare2 leftrigh libauth Spend1x dolex.

***   For further information about any command, you can right-click the command in
***   the syntax window and select Help - this will open a browser window and access
***   the relevant page from the SPSS Command Syntax Reference, a useful online tool. 
**
***   TASK:
***       Try accessing the relevant Help page for the FREQUENCIES or DESCRIPTIVES commands.

***   TASK:
***       Run a frequencies command on the Ragecat variable then write a note describing the values and distribution.
***       You can write a comment in the syntax file (remember, start a new line with a *) or 
***       on the dataset itself (hint: use the DOCUMENT command).
***       Remember to add a full stop to the end of your comment or command!

***   Let's take a look at some particular variables in more detail.
fre var=Ragecat DVSex21 Partyfwx.

***   It's often useful to examine variables by different categories of another variable (e.g. the age distribution for men and women).
CROSSTABS
  /TABLES=Ragecat BY DVSex21
  /FORMAT=AVALUE TABLES
  /CELLS=COUNT ROW
  /COUNT ROUND CELL.

***   We can look at the differences in different measures between men/women by age
***   for example, political party identification.
CROSSTABS
  /TABLES=Ragecat BY Partyfwx BY DVSex21
  /FORMAT=AVALUE TABLES
  /STATISTICS=CHISQ 
  /CELLS=COUNT ROW 
  /COUNT ROUND CELL.

***   TASK:
***       Write a note describing the values and distribution of the above variables.
***       You can write a comment in the syntax file or on the dataset itself.

***   The variables left-right scale (leftrigh), Libertarian-authoritarian (libauth) and the welfarism scale (welfare2) are 
***   constructed from responses to a set of items to give different attitude measured on a scale of 1-5.
***   We can explore the differences in responses on these attitudinal scales between men and women:.
means leftrigh by Ragecat.
means libauth by Ragecat.
means welfare2 by Ragecat.

***   TASK:
***      Copy one of these commands and adapt it to explore differences in attitudes between men and women
***      for one of the above scales:.



***   Quite often we are interested in a subset of cases.
temporary.
select if (Ragecat ge 1 and Ragecat le 6).
means welfare2 by Ragecat.

***   You can find out what the GE and LE qualifiers are by using the Help option (see lines 779-781).
***   You'll notice we used the TEMPORARY command. This ensures that we don't accidentally permanently delete 
***   cases that are not included by the 'select if' command (i.e. if we run line 830 without running 829 beforhand).

***   NOTE:
***   As we haven't modified out data in this section we don't need to save a version of ur data.
***   However, we have produced a number of outputs.
***   If you would like to save the output before you close a session (to save time running the commands each time),
***   you can do so with the SPSS menu (in the Output window: File > Save As) or you can use the code below (lines 847-849).

***   NOTE 1: You need to have run the DEFINE command to specify the location of your OUTPUT folder (line 229).
***   NOTE 2: When saving your output, add the date it was generated in the file name so you can easily
***   differentiate between multiple Output files.
***   NOTE 3: Remember, you need to remove the * at the beginning of the next line, or SPSS will ignore the command.
*OUTPUT SAVE NAME=Document1
OUTFILE=!OUTPUT+'MANTRA_output_20241005.spv'
LOCK=NO.



*****************************************************************.
*****************************************************************.

***   Part 6:   COMMON DATA MANAGEMENT TECHNIQUES.

***   In this section we're going to practice a number of common and crucial data management tasks.

***       1. Recoding variables - collapsing values/categories.
***       2. Recoding variables - binary / dummy variables.
***       3. Dealing with missing data.
***       4. Deleting variables.

*****************************************************************.
*****************************************************************.
***   1. Recoding variables - collapsing values/categories.

***   NOTE:
***       When recoding a variable, you should always create a new variable & NEVER DELETE THE ORIGINAL !!!
***       Use a naming convention so you can differentiate between the original & recoded variables
***       (e.g. a simple way is to add an _r suffix to the end of the new recoded variable name).

***  Combining categories of age group.
RECODE Ragecat (1 2=1)(3 4=2)(5 6 7=3)(else=-1) INTO Ragecat_3grp.
VARIABLE LABELS Ragecat_3grp 'Age group (3 group) - recoded from Ragecat'.
VALUE LABELS Ragecat_3grp 1 '18-34' 2 '35-54' 3 '55+' -1 'not available' .
MISSING VALUES Ragecat_3grp (-1).
FREQUENCIES VARIABLES=Ragecat_3grp.

***   You should always double check that the new variable has been correctly recoded.
CROSSTABS / tables= Ragecat_3grp by Ragecat / MISSING=INCLUDE.

***   TASK:
***       Using the RECODE, VARIABLE LABELS and VALUE LABELS commands (see 
***       lines 875-879) try collapsing categories of another categorical
***       variable of your choosing, and add variable and value labels.
***       For example, try recoding one of the EQOPP variables.
***       Remember to check the recode process worked (using the CROSSTABS command, line 882).







*****************************************************************.
*****************************************************************.
***  2. Recoding variables - binary / dummy variables.

***   For the purposes of certain analytical methods, it is often desirable to code categorical variables
***   into dichotomous 'dummy variable' indicators. The values involved should normally be set 
***   to 0 and 1, since this is the most convenient for many different purposes. For example:. 
fre var=hedqual2x.

** Let's create a dummy variable to indicate whether an individual has a degree (or equivalent):.
recode hedqual2x (1=1) (2, 3, 4=0) (else=sysmis) into degree.
VARIABLE LABELS degree 'Has a degree (or equivalent) - recoded from hedqual2x'.
VALUE LABELS degree 0 'No degree' 1 'Has degree'.
CROSSTABS / tables= hedqual2x  by degree / MISSING=INCLUDE.

*****************************************************************.
*****************************************************************.
***   3. Dealing with missing data .

***   We have already made several uses of 'missing data' commands above. 
***   Missing data occurs when information on a particular variable for a particular 
***   case is not available, either because it was not collected successfully (missing)
***   or perhaps because it is not relevant to the analysis ('inapplicable'). 

***   Conventionally, missing and inapplicable cases are coded with explicit values,  
***   usually negative numbers such as -999, -9,-7, -1, which remind an analyst that 
***   these cases are special cases.

*****************************************************************.
*****************************************************************.
***   4. Deleting variables. 

***   A useful command if we no longer need a recoded or derived variable.
***   REMEMBER - BE CAREFUL NOT TO DELETE THE ORIGINAL VARIABLE !!!.
* delete variables Ragecat_3grp.
* delete variables degree.

***   If we find that we need a recoded or derived variable again, we can just run the  
***   command/s to create it again - much easier than using the drop-down menu!.

*****************************************************************.
*****************************************************************.
***   Saving the SPSS file.

***   We've performed a bit of data management in this section, and created 2 new variables.
***   Let's save a new version of our SPSS data file.

sav out=!WORKING_DATA+'MANTRA_UKDA-9236-v3.sav'.

***   NOTE:
***       We add a version number suffix to the file name (e.g. -v3) which allows us to differentiate
***       between major changes in our our data. If we make a mistake (e.g. deleting variables/cases
***       by mistake) we can then easily revert back to the most recent version.

*****************************************************************.
*****************************************************************.
**
***   Part 7:   DATA LINKAGE: ADD CASES AND ADD FILES.

*****************************************************************.
*****************************************************************.

***   ADDING NEW VARIABLES.

***   Some data may have additional measures for the same individuals in one or more supplementary datasets, 
***   which may be linked to the core dataset using a shared common identifier.

***   Here we will add additional variables for the same set of individuals using the identifier 'serial_scrambled'.
***   Let's open our main SPSS file and sort it before we add additional variables.
get file=!WORKING_DATA+'MANTRA_UKDA-9236-v3.sav'.
EXECUTE.

sort cases by serial_scrambled.

***   See '11.1. Add variables from other dataset(s)' in the PDF workbook, PG. 36) on checking  
***   for duplicate values of the individual identifier (in this case, 'serial_scrambled').

***   Now let's save our sorted dataset.
sav out=!WORKING_DATA+'MANTRA_UKDA-9236-v3_sorted.sav'.

***   Let's perform the same functions on the file containing additional variables.
get file=!CLEAN_DATA+"MANTRA_UKDA-9236_ADDVARS.sav".
EXECUTE.

sort cases by serial_scrambled.

***   See '11.1. Add variables from other dataset(s)' in the PDF workbook, PG. 36) on checking
***   for duplicate values of the individual identifier (in this case, 'serial_scrambled').
sav out=!CLEAN_DATA+'MANTRA_UKDA-9236_ADDVARS_sorted.sav'.

***   Now let's merge our main data set with the dataset containing the additional variables.
get file=!WORKING_DATA+'MANTRA_UKDA-9236-v3_sorted.sav'.
EXECUTE.

display dictionary.

MATCH FILES FILE=!CLEAN_DATA+'MANTRA_UKDA-9236_ADDVARS_sorted.sav'
 /FILE=!WORKING_DATA+'MANTRA_UKDA-9236-v3_sorted.sav'
 /BY serial_scrambled.
SAVE OUTFILE =!WORKING_DATA+'MANTRA_UKDA-9236-v4.sav' /   KEEP=all / MAP.
display dictionary.

***   We should now have a file with 5,175 cases and 33 variables (note: you may have more  
***   variables created additional variables in the previous section).
get file=!WORKING_DATA+'MANTRA_UKDA-9236-v4.sav'.
EXECUTE.

sysfile info !WORKING_DATA+'MANTRA_UKDA-9236-v4.sav'.

*****************************************************************.
*****************************************************************.

***   ADDING NEW CASES.

***   In some cases you may wish to add additional cases to your data (e.g. responses on the same measure by different individuals).
***   For example, cross-sectional time-series (longitudinal data) commonly collects responses to the same questions at a different point in time.

***   Let's take a look at the file containing additional cases.
get file=!CLEAN_DATA+'MANTRA_UKDA-9236_ADDCASES.sav'.
EXECUTE.

display dictionary.
sysfile info !CLEAN_DATA+'MANTRA_UKDA-9236_ADDCASES.sav'.

***   How many cases are contained in this file? .
***   How many variables are contained in this file? .


***   Before we link the datasets we can also check information about our core data file again.
sysfile info !WORKING_DATA+'MANTRA_UKDA-9236-v4.sav'.

***   Let's add the additonal cases.
add files file=!WORKING_DATA+'MANTRA_UKDA-9236-v4.sav'
     /file= !CLEAN_DATA+'MANTRA_UKDA-9236_ADDCASES.sav'.
EXECUTE.

sav out=!WORKING_DATA+'MANTRA_UKDA-9236-v5.sav'.
display dictionary.
sysfile info !WORKING_DATA+'MANTRA_UKDA-9236-v5.sav'.

***   Do we have the correct number of cases?.
***   Our main dataset should now contain 6,250 cases with 33 variables.
***   NOTE: the number of variables in your data may be different, for example if you  created additional variables, or deleted ones we created earlier.

*****************************************************************.
*****************************************************************.

**
***   Part 8:   EXPORTING DATA TO OTHER FORMATS.

***   This is another of those tasks that is more easily conducted using the drop-down menu.

***   TASK:
***       Export your data to .csv format using the Menu (in the Data Editor: File > Export > CSV Data)
***       Give the file a suitable name, and include today's date in the filename (format: YYYYMMDD).

**********************************************************************************.
**********************************************************************************.

***    FINAL POINTS:.
***       Your syntax file will develop as your research progresses, to incorporate all data management  
***       and preparation activities (e.g. opening or importing your data, adding labels, recoding and 
***       deriving new variables) as well as the steps you took to conduct your analysis (e.g. how you 
***       produced your tables and graphs, how your regression models were specified). This will ensure  
***       your data and analysis can be modified as required. This will also ensure that you (or anyone you 
***       share your syntax files with) can replicate your research, and will make answering questions about 
***       your work much easier.


** End Of File.
COMMENT BOOKMARK;LINE_NUM=367;ID=6.
COMMENT BOOKMARK;LINE_NUM=715;ID=7.
COMMENT BOOKMARK;LINE_NUM=855;ID=8.
COMMENT BOOKMARK;LINE_NUM=953;ID=9.
